# satproc

Python library and CLI tools for processing geospatial imagery for ML

[![](https://img.shields.io/pypi/v/pysatproc.svg)](https://pypi.python.org/pypi/pysatproc)
[![](https://img.shields.io/github/issues-closed/dymaxionlabs/satproc)](https://github.com/dymaxionlabs/satproc/issues)
![](https://img.shields.io/github/license/dymaxionlabs/satproc)

## Documentation

* [Stable](https://satproc.readthedocs.io/en/stable/)
* [Latest](https://satproc.readthedocs.io/en/latest/)

## Bugs / Questions

* [Report bugs/feature requests](https://github.com/dymaxionlabs/satproc/issues)
* [Ask questions](https://github.com/dymaxionlabs/satproc/discussions)

## Contributing

Bug reports and pull requests are welcome on GitHub at the [issues
page](https://github.com/dymaxionlabs/satproc). This project is intended to be
a safe, welcoming space for collaboration, and contributors are expected to
adhere to the [Contributor Covenant](http://contributor-covenant.org) code of
conduct.

## License

This project is licensed under Apache 2.0. Refer to [LICENSE.txt](./LICENSE.txt).
